AuthMethod enum
The mechanism that produced the AuthResult.
Values
- biometric → const AuthMethod
-
Face ID, Touch ID, or a fingerprint sensor was used.
- deviceCredential → const AuthMethod
-
A PIN, pattern, or password was used as a fallback.
- gracePeriod → const AuthMethod
-
The prompt was skipped because the device was recently unlocked.
- none → const AuthMethod
-
No authentication took place (e.g. AuthStatus.notAvailable or AuthStatus.error).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AuthMethod> - A constant List of the values in this enum, in order of their declaration.